@@ -29,7 +29,7 @@ class MsMarcoDocument(NamedTuple):
 # Use the TREC-formatted docs so we get all the available formatting (namely, line breaks)
 class MsMarcoTrecDocs(TrecDocs):
     def __init__(self, docs_dlc):
-        super().__init__(docs_dlc, parser='text')
+        super().__init__(docs_dlc, parser='text', lang='en')
 
     @ir_datasets.util.use_docstore
     def docs_iter(self):
@@ -60,40 +60,41 @@ def _init():
 
     subsets['train'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['train/queries']), namespace='msmarco'),
+        TsvQueries(GzipExtract(dlc['train/queries']), namespace='msmarco', lang='en'),
         TrecQrels(GzipExtract(dlc['train/qrels']), QRELS_DEFS),
         TrecScoredDocs(GzipExtract(dlc['train/scoreddocs'])),
     )
 
     subsets['dev'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['dev/queries']), namespace='msmarco'),
+        TsvQueries(GzipExtract(dlc['dev/queries']), namespace='msmarco', lang='en'),
         TrecQrels(GzipExtract(dlc['dev/qrels']), QRELS_DEFS),
         TrecScoredDocs(GzipExtract(dlc['dev/scoreddocs'])),
     )
 
     subsets['eval'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['eval/queries']), namespace='msmarco'),
+        TsvQueries(GzipExtract(dlc['eval/queries']), namespace='msmarco', lang='en'),
         TrecScoredDocs(GzipExtract(dlc['eval/scoreddocs'])),
     )
 
     subsets['trec-dl-2019'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['trec-dl-2019/queries']), namespace='msmarco'),
+        TsvQueries(GzipExtract(dlc['trec-dl-2019/queries']), namespace='msmarco', lang='en'),
         TrecQrels(dlc['trec-dl-2019/qrels'], TREC_DL_QRELS_DEFS),
         TrecScoredDocs(GzipExtract(dlc['trec-dl-2019/scoreddocs'])),
     )
 
     subsets['trec-dl-2020'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['trec-dl-2020/queries']), namespace='msmarco'),
+        TsvQueries(GzipExtract(dlc['trec-dl-2020/queries']), namespace='msmarco', lang='en'),
+        TrecQrels(dlc['trec-dl-2020/qrels'], TREC_DL_QRELS_DEFS),
         TrecScoredDocs(GzipExtract(dlc['trec-dl-2020/scoreddocs'])),
     )
 
     subsets['orcas'] = Dataset(
         collection,
-        TsvQueries(GzipExtract(dlc['orcas/queries']), namespace='orcas'),
+        TsvQueries(GzipExtract(dlc['orcas/queries']), namespace='orcas', lang='en'),
         TrecQrels(GzipExtract(dlc['orcas/qrels']), ORCAS_QLRES_DEFS),
         TrecScoredDocs(GzipExtract(dlc['orcas/scoreddocs'])),
     )
@@ -105,6 +106,13 @@ def _init():
         subsets['trec-dl-2019'],
     )
 
+    dl20_judged = Lazy(lambda: {q.query_id for q in subsets['trec-dl-2020'].qrels_iter()})
+    subsets['trec-dl-2020/judged'] = Dataset(
+        FilteredQueries(subsets['trec-dl-2020'].queries_handler(), dl20_judged),
+        FilteredScoredDocs(subsets['trec-dl-2020'].scoreddocs_handler(), dl20_judged),
+        subsets['trec-dl-2020'],
+    )
+
     ir_datasets.registry.register('msmarco-document', Dataset(collection, documentation("_")))
     for s in sorted(subsets):
         ir_datasets.registry.register(f'msmarco-document/{s}', Dataset(subsets[s], documentation(s)))
